bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 18. Aventiure
___________________________________________________ #### Aventivre wie chriemhilt da bestvnt #### vnd ir sweher dannen reit
###### 1073 | ### Der sweher criemhilde | gie dar er si vant ### er sprach cer chveneginne | wir svln in vnser lant ### wir waen vnmaere geste | bi dem rine sin ### criemhilt vil liebiv vrowe | nv vart ir zv den landen min
###### 1074 | ### sit daz vns vntriwe | ane hat getan ### hi in disen landen | des iwern edeln man ### des svlt ir niht engelten | ich vil iv waege sin ### dvrch mines svns liebe | des svlt ir ane zwivel sin
###### 1075 | ### ir svlt haben vrowe | allen den gewalt ### den iv e taete chvnde | sifrit der degen balt ### daz lant vnd ovch div chrone | daz si iv vndertan ### iv svln gerne dienen | alle sifrides man
###### 1076 | ### do saget man den chnehten | si solden riten dan ### do wart ein michel gahen | nach rossen getan ### bi ir starchen vienden was | in ze wesin leit ### den vrowen vnt den megden | hiez man svchen div chleit
###### 1077 | ### do der kvnich sigemvnt | wolde sin geriten ### do begonde criemhilt | di ir mage biten ### daz si bi ir mvter | solde da bestan ### do sprach div vrowe herre | daz chvnde niemer ergan
###### 1078 | ### wi mohten ich den immer | mit ovgen angesehen ### von dem mir armem wibe | so leide ist geschehen ### do sprach der ivnge giselher | vil liebiv swester min ### dv solt dvrch dine triwe | hi bi diner mvter sin
###### 1079 | ### di dich da habent beswaerent | vnde betrvebet den mvt ### der bedarftv niht ce dienste | nv zer min eines gvt ### si sprach zv dem rechen | ia ne mag es niht geschehen ### vor leide mvoz ich sterben | swenne ich hagenen mvse sehen
###### 1080 | ### des tvn ich dir ce rate | vil liebiv swester min ### dv solt bi dinem brvder | giselhere sin ### ia wil ich dich ergezzen | dines mannes tot ### do sprach div gotes arme | des waere criemhilde not
###### 1081 | ### do ez ir der ivnge giselher | so gvetlich erbot ### do begonde vlegen | vte vnd gernot ### vnd ir getriwe mage | si baten si da bestan ### si hete lvecel chvennes | vnder sifrides man
###### 1082 | ### si sint iv alle vremde | so sprach gernot ### ez en lebet so starcher niemen | er ne mveze ligen tot ### daz bedencht liebiv swester | vnd troestet iwern mvt ### belibt bi den vrivnden | daz wirt iv waerlichen gvt
###### 1083 | ### si lobte giselhern | si wolde da bestan ### div ross gezogen waren | den sigemvndes man ### als si wolden riten | cer nibelvnge lant ### do was ovch vfgesovmet | al der recken gewant
###### 1084 | ### do gie der herre sigemvnt | zv criemhilde stan ### er sprach zv der vrowen | di sifrides man ### nv warten bi den rossen | nv svl wir riten hin ### wand ich vil vngerne | bi den bvergonden bin
###### 1085 | ### do sprach div vrowe criemhilt | mir ratent di vrivnde min ### swaz ich han getriwen | ich svl hie bi in sin ### ich habe niemen mage | in nibelvnge lant ### vil leit was iz sigemvnde | do erz an criemhilde ervant
###### 1086 | ### do sprach der kvenich sigemvnt | lat iv niemen sagen ### vor allen minen magen | svlt ir di chrone tragen ### also gewaltechliche | als ir e habt getan ### ir en svlt des niht engelten | daz wir den helt verloren han
###### 1087 | ### vnd vart ovch mit vns wider | dvrch iwer chindelin ### daz en svlt ir niht vrowe | weise lazen sin ### swenne iwer svn gewahset | der trostet iv den mvt ### di wile sol iv dienen | manich helt chvne vnd gvt
###### 1088 | ### si sprach herre sigemvnt | ia ne mach ich riten niht ### ich mvz hie beliben | swaz halt mit geschit ### bi den minen magen | di mir helfen chlagen ### do begonden disiv maere | den gvten recken missehagen
###### 1089 | ### si sprachen al geliche | so moehte wir wol iehen ### daz vns allererste | waere leit geschehen ### woldet ir beliben | bi vnsern vinden hie ### so geritten hovereise | noch helde sorchlicher nie
###### 1090 | ### ir svlt ane sorge | got bevolhen varn ### man git iv gvt geleite | ich heiz ivch wol bewarn ### zv sigemvndes lande | min liebez chindelin ### daz sol vf genade | iv rechen wol bevolhen sin
###### 1091 | ### do si wol vernamen | daz si niht wolde dan ### do weinten al geliche | di sigemvndes ### wi rehte iamerlichen | schiet do sigemvnt ### von vrovn criemhilde | do was im vngemvete chvnt
###### 1092 | ### so we der hohgecite | sprach do der kvnech her ### ez geschit von chvrcewile | hinfvr nimmer mer ### kvnige noch sinen magen | daz vns ist geschehen ### man sol nimmer mere | hi cen bvergonden sehen
###### 1093 | ### do sprachen offenliche | di sigemvndes man ### ez mohte noch div reise | in diz lant ergan ### so wir den reht erfinden | der vns den herren slvch ### si habent von sinen magen | starcher viende genvch
###### 1094 | ### er chvste criemhilden | wi iamerlichn er sprach ### do si beliben wolde | vnd er daz reht ersach ### nv riten vrevden ane | heim in vnser lant ### alle mine sorge | sint mir erste nv bechant
###### 1095 | ### si riten an geleite | von wormez an den rin ### si mohten wol des mvtes | vil sicherlichen sin ### ob si in vientschepfte | wuerden angerant ### daz sich weren wolde | der chvnen nibelvnge hant
###### 1096 | ### si ne gerten vrlovbes | da ze cheinem man ### do sah man gernot | vnd giselheren gan ### zv zim minnechlichen | im was sin schade leit ### des brahten in wol inne | di helde chvne vnt gemeit
###### 1097 | ### do sprach gezogenlichen | der fvrste gernot ### got weiz daz wol von himele | an sifrides tot ### gewan ich nie di schvlde | daz ich daz horte sagen ### wer im hie vient waere | ich sol in pilliche chlagen
###### 1098 | ### do gab in gvt geleite | giselher daz chint ### er brahte sorgende | vz dem lande sint ### den kvenich mit sinen recken | heim ce niderlant ### wi lvecel man der mage | darinne vroelichen vant
###### 1099 | ### wi si nu gefveren | des chan ich niht gesagen ### man horte hie zallen ziten | criemhilde chlagen ### daz ir niemen troste | daz herce vnt ovch den mvt ### ez en taete giselher | der was getriwe vnde gvt
###### 1100 | ### prvnhilt div schoene | mit vbermvete saz ### swaz geweinte criemhilt | vnmaer was ir daz ### si ne wart ir gvter triwe | nimmerme bereit ### sit getet ir ovch vrov criemhilt | div vil hercenlichen leit

<<< Übersicht <<< vorige Seite nächste Seite >>>